@@ -1,18 +1,16 @@
-# $Id: Iterator.pm 2746 2007-10-19 16:36:50Z andy $
+use 5.008; use warnings; use strict;
+
 package Parallel::Iterator;
 
-use warnings;
-use strict;
 use Carp;
 use Storable qw( store_fd fd_retrieve dclone );
 use IO::Handle;
 use IO::Select;
 use Config;
 
-require 5.008;
+our $VERSION = '1.001';
 
-our $VERSION = '1.00';
-use base qw( Exporter );
+use Exporter (); *import = \&Exporter::import;
 our @EXPORT_OK = qw( iterate iterate_as_array iterate_as_hash );
 
 use constant IS_WIN32 => ( $^O =~ /^(MS)?Win32$/ );
@@ -29,10 +27,6 @@ my %DEFAULTS = (
 
 Parallel::Iterator - Simple parallel execution
 
-=head1 VERSION
-
-This document describes Parallel::Iterator version 1.00
-
 =head1 SYNOPSIS
 
     use Parallel::Iterator qw( iterate );
@@ -50,13 +44,13 @@ This document describes Parallel::Iterator version 1.00
     while ( my ( $index, $value ) = $iter->() ) {
         $out[$index] = $value;
     }
-  
-=head1 DESCRIPTION
 
 The C<map> function applies a user supplied transformation function to
 each element in a list, returning a new list containing the
 transformed elements.
 
+=head1 DESCRIPTION
+
 This module provides a 'parallel map'. Multiple worker processes are
 forked so that many instances of the transformation function may be
 executed simultaneously. 
@@ -69,7 +63,9 @@ There is, however, a considerable overhead associated with forking, so
 the example in the synopsis (doubling a list of numbers) is I<not> a
 sensible use of this module.
 
-=head2 Example
+=head1 MANUAL
+
+=head2 Basic Usage
 
 Imagine you have an array of URLs to fetch:
 
@@ -84,7 +80,7 @@ Write a function that retrieves a URL and returns its contents or undef
 if it can't be fetched:
 
     sub fetch {
-        my $url = shift;
+        my ($id, $url) = @_;
         my $resp = $ua->get($url);
         return unless $resp->is_success;
         return $resp->content;
@@ -144,9 +140,9 @@ value pairs:
 If the returned iterator is inconvenient you can get back a hash or
 array instead:
 
-    my @done = iterate_as_array( \&fetch, @urls );
+    my @done = iterate_as_array( \&fetch, \@urls );
 
-    my %done = iterate_as_hash( \&worker, %jobs );
+    my %done = iterate_as_hash( \&worker, \%jobs );
 
 =head2 How It Works
 
@@ -174,7 +170,7 @@ process. That means that things like this won't work as expected:
         my ($id, $name) = @_;
         $tally{$name}++;       # might not do what you think it does
         return reverse $name;
-    }, @names );
+    }, \@names );
 
     # Now print out the tally...
     while ( my ( $name, $count ) = each %tally ) {
@@ -675,19 +671,12 @@ sub _put_obj {
 }
 
 1;
+
 __END__
 
-=head1 CONFIGURATION AND ENVIRONMENT
-  
-Parallel::Iterator requires no configuration files or environment variables.
+=pod
 
-=head1 DEPENDENCIES
-
-None.
-
-=head1 INCOMPATIBILITIES
-
-None reported.
+=encoding UTF-8
 
 =head1 BUGS AND LIMITATIONS
 
@@ -697,40 +686,19 @@ Please report any bugs or feature requests to
 C<bug-parallel-iterator@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
-=head1 AUTHOR
-
-Andy Armstrong  C<< <andy@hexten.net> >>
-
 =head1 THANKS
 
 Aristotle Pagaltzis for the END handling suggestion and patch.
 
-=head1 LICENCE AND COPYRIGHT
+=head1 AUTHOR
 
-Copyright (c) 2007, Andy Armstrong C<< <andy@hexten.net> >>. All rights reserved.
+Andy Armstrong <andy@hexten.net>
 
-This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself. See L<perlartistic>.
+=head1 COPYRIGHT AND LICENSE
 
-=head1 DISCLAIMER OF WARRANTY
+This software is copyright (c) 2007 by Andy Armstrong.
 
-BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
-OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
-PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
-EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
-ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
-YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
-NECESSARY SERVICING, REPAIR, OR CORRECTION.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
-LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
-OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
-THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
-RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
-FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
-SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
-SUCH DAMAGES.
+=cut
